Meta-tool that presents frames from a video to image analysis frameworks and uses the predictions to determine whether to use a frame or not.

Project page:

https://github.com/waikato-datamining/video-frame-selector
